@@ -28,9 +28,10 @@
 
 enum {
 	COL_ACTIVE,
-	COL_SERVICE,
-	COL_PRIORITY,
+	COL_DESC,
+	COL_IMAGE,
 	COL_POINTER,
+	COL_DANGEROUS,
 	COL_LAST
 };
 
